@@ -1,8 +1,8 @@
-# $Id: Subclass.pm 26604 2006-10-17 20:52:48Z wsnyder $
+# $Id: Subclass.pm 29376 2007-01-02 14:50:38Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2006 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2007 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 #
@@ -15,10 +15,9 @@
 
 package SystemC::Vregs::Subclass;
 
-use strict;
-use vars qw($Errors $VERSION);
+use strict;use vars qw($Errors $VERSION);
 use Carp;
-$VERSION = '1.421';
+$VERSION = '1.430';
 
 $Errors = 0;
 
@@ -164,7 +163,7 @@ Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
 suite.  The latest version is available from CPAN and from
 L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
 
-Copyright 2001-2006 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2007 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
